@@ -1,7 +1,7 @@
 package ShellQuote::Any::Tiny;
 
-our $DATE = '2017-09-19'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $DATE = '2017-09-20'; # DATE
+our $VERSION = '0.007'; # VERSION
 
 use strict;
 #use warnings;
@@ -19,9 +19,8 @@ sub shell_quote {
         if ($arg =~ /\A\w+\z/) {
             return $arg;
         }
-        # escape backslash that is followed by a backslash, or the last
-        # backslash
-        $arg =~ s/(\\(?!.*\\)|\\(?=\\)|")/\\$1/g;
+        $arg =~ s/\\(?=\\*(?:"|$))/\\\\/g;
+        $arg =~ s/"/\\"/g;
         return qq("$arg");
     } else {
         if ($arg =~ /\A\w+\z/) {
@@ -47,7 +46,7 @@ ShellQuote::Any::Tiny - Escape string for the Unix/Windows shell
 
 =head1 VERSION
 
-This document describes version 0.006 of ShellQuote::Any::Tiny (from Perl distribution ShellQuote-Any-Tiny), released on 2017-09-19.
+This document describes version 0.007 of ShellQuote::Any::Tiny (from Perl distribution ShellQuote-Any-Tiny), released on 2017-09-20.
 
 =head1 SYNOPSIS
 
